@@ -10,8 +10,8 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "allocateSO3CoeffsSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abc4a61da919ae37b0a03d23df2461224", null ],
     [ "allocateWignerMatricesSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aea644c87703e005507e187aa0ffa64b7", null ],
     [ "centreMapOnCOM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a80ff45ef40549fb6a1d80b70865fc807", null ],
-    [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2b60ba4e2dd8ef4918b6f0ea5316a009", null ],
-    [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a60643383ab239888adeee6e757876c80", null ],
+    [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7c9b62338517f1da1693b1073ebc9389", null ],
+    [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a42419398083b05da19ebfb3cfa5cdc34", null ],
     [ "computeRotatedSH", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad39f33c52f6d4f0db8e0d63ed0c9a2f3", null ],
     [ "computeRotationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac7cb89ed871668c57a3b5dc953c20482", null ],
     [ "computeRRPMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a6db2dcf87a6f763909ab08201e8de550", null ],
@@ -24,13 +24,12 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "figureIndexStartStop", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a476092aa08dff20d64a895e7b2227b2e", null ],
     [ "findMapCOM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac07955296611dd411cf5ed87ced90571", null ],
     [ "findRequestedCSymmetryFromAngleAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2714fcb2c08b224ccf09d64322bd2ab2", null ],
-    [ "findTopGroupSmooth", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a671ebb0985408bff451ec359b4df79b9", null ],
     [ "getAllGroupElements", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae2f2469c7d252c5e87d7bf9976b9b796", null ],
+    [ "getAllGroupElements", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afc06f274535401086eefad02fcc8ac10", null ],
     [ "getAnySphereRadius", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a23620b34a604aca7db4d8b21f6d2d09a", null ],
     [ "getBestRotationMapPeaksEulerAngles", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a129f0b665c31fe2d6c7a03f1ba9997de", null ],
     [ "getBestTranslationMapPeaksAngstrom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a53412a6bef001a7be8fd98ceaa8a8648", null ],
     [ "getComparisonBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a6cc2b8e179a137adda234e0ba0f9d27b", null ],
-    [ "getCyclicSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a421d8cf46b6671857d0054cf0defe17f", null ],
     [ "getCyclicSymmetriesListFromAngleAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afa3b1a8ef870a606035102b5dcf1ce44", null ],
     [ "getDihedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a1fdc5b9df47ff8de3a5f2f6e6ce233a5", null ],
     [ "getEMatrixByBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a94a73f81ba80621f5f52173e91bb47f7", null ],
@@ -94,7 +93,7 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "maskMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0122be830893f5d82bab742be54d1ee7", null ],
     [ "normaliseEMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aceb19c915cebcef22c085cc6619cc472", null ],
     [ "normaliseMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a255bdb77824ce0fddc2454d5823219e1", null ],
-    [ "prepareFSCFourierMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a51b1eb3cb274c1c68e85cf3cca0c25b7", null ],
+    [ "prepareFSCFourierMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#acf2c2c9634a9e641270f8889624c3752", null ],
     [ "processInternalMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afcb4202e9ffea1b99c59f73faf06d899", null ],
     [ "readInGemmi", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#af8dcc353f075b824d2f3479f487c8bd0", null ],
     [ "readInMAP", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aae85fef5742e6c6c9ef7bda2ff0f7d23", null ],
@@ -109,9 +108,9 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "rotateMapRealSpaceInPlace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac626ea4513155170cff98fd18e6f3b09", null ],
     [ "rotateMapReciprocalSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa12ba3d9d61e240ec2d91d924e6cb0d3", null ],
     [ "saveDetectedSymmetries", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0b0608e80f20087b24cc9498767f0894", null ],
-    [ "saveRecommendedSymmetry", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a262b3b0e1129d4d3a5830a8982395f01", null ],
+    [ "saveRecommendedSymmetry", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad9b0fec5092eed1ab485443c15289e14", null ],
     [ "saveRequestedSymmetryC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a599a8fa1d6d780a45a2d772413bc778e", null ],
-    [ "saveRequestedSymmetryD", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a51fec3f0a115640181f6e7ce102e4b37", null ],
+    [ "saveRequestedSymmetryD", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa200af7e84ec7a17ecfd54a45a8ffafe", null ],
     [ "setEMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aca5af5c8c3b18275e65ae4ebacd9877c", null ],
     [ "setIntegrationWeight", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3e7b1d5d4164ea7a6fda53c57ac979f4", null ],
     [ "setIntegrationWeightCumul", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a737ee01d968fef7ae1094847a0271033", null ],
@@ -119,6 +118,8 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "setSO3CoeffValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aca5e27540622190be41ce78157c0807e", null ],
     [ "setWignerMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ab3aa4cdcd7cc9b458d7618077dfaab02", null ],
     [ "shellBandExists", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ada8e6f27f49afc3a0ee17758ce9e7594", null ],
+    [ "shiftToBoxCentre", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7e36b0876ff78682480a8ec22f3f5264", null ],
+    [ "shiftToRotationCentre", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad8694002911669527ca6266c66285d57", null ],
     [ "so3CoeffsArrayIndex", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9f6ba75b25e201466929bfd4df75688d", null ],
     [ "translateMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7170576d4823143e7dd270e0f202d0b4", null ],
     [ "writeGemmi", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a291d70d6d298ce4094b625f588c83b1c", null ],
