@@ -85,9 +85,9 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "_pro_s_h_a_d_e_8cpp.html",
-"_pro_s_h_a_d_e__spherical_harmonics_8hpp.html#a38c2dcddc09fd31877eecb17f1d84aa7",
+"_pro_s_h_a_d_e__settings_8hpp.html",
 "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9b08a8b6f9569c06cd183c924e6e80de",
-"class_pro_s_h_a_d_e__settings.html#a833f51d5da64ed09004daa4bf66c013c"
+"class_pro_s_h_a_d_e__settings.html#a754c633261eb363bfb496a234ace79e6"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
