@@ -1,6 +1,6 @@
 ######################################################
 ######################################################
-#   \file getMaskedSymmetryPredictions.py
+#   \file getMaskedSymmetryPredictions_centre.py
 #   \brief This file shows how ProSHADE can be used in conjunction with EMDA to improve the symmetry predictions.
 #
 #   This code allows a simple symmetry detection run on a long list of EMDB structures (assuming these are downloaded
@@ -30,8 +30,8 @@
 #
 #   \author    Michal Tykac
 #   \author    Garib N. Murshudov
-#   \version   0.7.6.0
-#   \date      JUL 2021
+#   \version   0.7.6.3
+#   \date      FEB 2022
 ######################################################
 ######################################################
 
@@ -74,12 +74,14 @@ import emda.emda_methods as emda_methods
 resolution                                            = 8.0
 minimalAllowedResolution                              = 20.0
 mapReSampling                                         = True
-mapCentering                                          = True
+symmetryCentering                                     = False
+comCentering                                          = True
+verbosity                                             = -1
 inputFileName                                         = "emdb_spa_210329.dat"
-outputFileName                                        = "results_allKnownEMDB_resol-"
+outputFileName                                        = "results_allKnownEMDB_COM_resol-"
 EMDBDataPath                                          = "/Users/mysak/BioCEV/proshade/xx_EMDBSymmetry"
-unreleasedIDsList                                     = [ "EMD-10163", "EMD-10165", "EMD-10166", "EMD-10168", "EMD-10169", "EMD-10170", "EMD-10174", "EMD-21320", "EMD-4320", "EMD-4522", "EMD-4523", "EMD-4524", "EMD-4606", "EMD-4607", "EMD-4718", "EMD-5039", "EMD-6758", "EMD-8144", "EMD-8145" ]
-tooLargeIDsList                                       = [ "EMD-0174", "EMD-11111", "EMD-20091", "EMD-21648", "EMD-0880", "EMD-11008", "EMD-0436", "EMD-11040", "EMD-0618" ]
+unreleasedIDsList                                     = [ "EMD-10163", "EMD-10165", "EMD-10166", "EMD-10168", "EMD-10169", "EMD-10170", "EMD-10174", "EMD-21320", "EMD-4320", "EMD-4522", "EMD-4523", "EMD-4524", "EMD-4606", "EMD-4607", "EMD-4718", "EMD-5039", "EMD-6758", "EMD-8144", "EMD-8145", "EMD-1300" ]
+tooLargeIDsList                                       = [ "EMD-0174", "EMD-11111", "EMD-20091", "EMD-21648", "EMD-0880", "EMD-11008", "EMD-0436", "EMD-11040", "EMD-0618", "EMD-10768" ]
 
 ######################################################
 ### Local settings
@@ -109,25 +111,29 @@ for writing, otherwise for appending.
 """
 def openOutputFiles ( cntr ):
     ### Declare local variables
+    outResRecom                                       = ""
     outResCondensed                                   = ""
     outResAxes                                        = ""
 
     ### Open files for output
     if cntr == 0:
         outResCondensed                               = open ( outputFileName + str ( resolutionFilename ) + "_condensed.txt", "w")
+        outResRecom                                   = open ( outputFileName + str ( resolutionFilename ) + "_recommended.txt", "w")
         outResAxes                                    = open ( outputFileName + str ( resolutionFilename ) + ".txt", "w")
     else:
         outResCondensed                               = open ( outputFileName + str ( resolutionFilename ) + "_condensed.txt", "a")
+        outResRecom                                   = open ( outputFileName + str ( resolutionFilename ) + "_recommended.txt", "a")
         outResAxes                                    = open ( outputFileName + str ( resolutionFilename ) + ".txt", "a")
         
-    return                                            ( outResCondensed, outResAxes )
+    return                                            ( outResRecom, outResCondensed, outResAxes )
 
 """
 This function closes the output files. This is done after each symmetry prediction
 to make sure results are written out after each step.
 """
-def closeOutputFiles ( outResCondensed, outResAxes ):
+def closeOutputFiles ( outResRecom, outResCondensed, outResAxes ):
     ## Close output files
+    outResRecom.close                                 ( )
     outResCondensed.close                             ( )
     outResAxes.close                                  ( )
 
@@ -221,6 +227,7 @@ def checkMapResolution ( mapFile, declRes ):
     locRes                                            = resolution
 
     ### Read in map using mrc file
+    print ( mapFile )
     mrc                                               = mrcfile.open ( mapFile, mode = "r+" )
 
     ### Find dims in Angstroms
@@ -275,7 +282,7 @@ def maskMapUsingEMDA ( mapFile, locRes ):
 This function runs ProSHADE symmetry detection and returns the recommented symmetry type,
 fold and a list of all detected C axes.
 """
-def runProSHADESymmetry ( mapFile, maskFile, resol, chngSampl, cntrMap ):
+def runProSHADESymmetry ( mapFile, maskFile, resol, chngSampl, cntrMap, symCenMap, verbosity ):
     ### Run proshade symmetry detection on the map
     pSet                                              = proshade.ProSHADE_settings ( )
 
@@ -284,8 +291,9 @@ def runProSHADESymmetry ( mapFile, maskFile, resol, chngSampl, cntrMap ):
     pSet.setResolution                                ( resol )
     pSet.setMapResolutionChange                       ( chngSampl )
     pSet.setMapCentering                              ( cntrMap )
-    pSet.verbose                                      = -1
+    pSet.verbose                                      = verbosity
     pSet.setAppliedMaskFilename                       ( maskFile )
+    pSet.setSymmetryCentreSearch                      ( symCenMap )
 
     ### Print major settings
     print ( " ... Running: res = " + str( resol ) + " mask = " + str( maskFile ) )
@@ -294,6 +302,103 @@ def runProSHADESymmetry ( mapFile, maskFile, resol, chngSampl, cntrMap ):
     pStruct                                           = proshade.ProSHADE_data ( )
     pStruct.readInStructure                           ( mapFile, 0, pSet )
 
+    ### Should we search for symmetry centre?
+    if pSet.findSymCentre:
+        ### Start centre detection - create the settings objects for the phaseless and phased centre detection runs
+        rotCenSettingsPhased                          = proshade.ProSHADE_settings ( pSet )
+        rotCenSettingsUnphased                        = proshade.ProSHADE_settings ( pSet )
+    
+        ### Enforce the necessary settings
+        rotCenSettingsPhased.messageShift             = 1;
+        rotCenSettingsPhased.moveToCOM                = False;
+        rotCenSettingsUnphased.usePhase               = False;
+        rotCenSettingsUnphased.requestedSymmetryType  = "onlyC";
+        rotCenSettingsUnphased.moveToCOM              = False;
+        rotCenSettingsUnphased.addExtraSpace          = pSet.addExtraSpace * 5.0;
+            
+        ###  Read in the structure and find all symmetries without using phase information
+        symStr                                        = proshade.ProSHADE_data ( )
+        symStr.readInStructure                        ( mapFile, 0, rotCenSettingsUnphased )
+        symStr.processInternalMap                     ( rotCenSettingsUnphased )
+        symStr.mapToSpheres                           ( rotCenSettingsUnphased )
+        symStr.computeSphericalHarmonics              ( rotCenSettingsUnphased )
+        symStr.computeRotationFunction                ( rotCenSettingsUnphased )
+        symStr.detectSymmetryInStructure              ( rotCenSettingsUnphased )
+    
+        ### Find reliable symmetries in the Patterson map
+        relSym                                        = proshade.findReliableUnphasedSymmetries ( rotCenSettingsUnphased, rotCenSettingsUnphased.verbose, rotCenSettingsUnphased.messageShift, rotCenSettingsUnphased.axisErrTolerance );
+        
+        ### Are there any reasonable symmetries?
+        if len ( relSym ) != 0:
+        
+            ### If there is a D, then optimise it
+            if len ( relSym ) == 2:
+                proshade.optimiseDGroupAngleFromAxesHeights ( relSym, symStr, rotCenSettingsUnphased )
+                
+            ### Get all axes
+            allCAxes                                  = symStr.getAllCSyms ( rotCenSettingsUnphased )
+                
+            ### Read in with phases
+            del symStr
+            symStr                                    = proshade.ProSHADE_data ( )
+            symStr.readInStructure                    ( mapFile, 0, rotCenSettingsPhased )
+            symStr.processInternalMap                 ( rotCenSettingsPhased )
+            
+            ### If single axis, determine point closest to COM
+            if len( relSym ) == 1:
+            
+                ### Find the line and point on it closest to COM
+                point1                                = proshade.findPointFromTranslations ( rotCenSettingsPhased, symStr, allCAxes, relSym[0] )
+                axis1                                 = numpy.array( [ allCAxes[relSym[0]][1], allCAxes[relSym[0]][2], allCAxes[relSym[0]][3]] )
+                COM                                   = proshade.findMAPCOMValues ( symStr )
+                
+                xBoxCentre                            = ( ( symStr.xTo - symStr.xFrom ) / 2 ) + symStr.xFrom
+                yBoxCentre                            = ( ( symStr.yTo - symStr.yFrom ) / 2 ) + symStr.yFrom
+                zBoxCentre                            = ( ( symStr.zTo - symStr.zFrom ) / 2 ) + symStr.zFrom
+                
+                COMFromBoxCen                         = numpy.zeros ( 3 )
+                COMFromBoxCen[0]                      = xBoxCentre - ( COM[0] / ( symStr.xDimSize / symStr.xDimIndices ) )
+                COMFromBoxCen[1]                      = yBoxCentre - ( COM[1] / ( symStr.yDimSize / symStr.yDimIndices ) )
+                COMFromBoxCen[2]                      = zBoxCentre - ( COM[2] / ( symStr.zDimSize / symStr.zDimIndices ) )
+                
+                alpha1                                = numpy.dot ( point1 - COMFromBoxCen, axis1 ) / numpy.dot ( axis1, axis1 )
+                
+                cpVec                                 = numpy.zeros ( 3 )
+                cpVec[0]                              = point1[0] + ( alpha1 * axis1[0] )
+                cpVec[1]                              = point1[1] + ( alpha1 * axis1[1] )
+                cpVec[2]                              = point1[2] + ( alpha1 * axis1[2] )
+                
+                pSet.setSymmetryCentrePosition        ( cpVec )
+            
+            ### If dihedral, find exact point
+            if len( relSym ) == 2:
+                
+                ### Find the point
+                point1                                = proshade.findPointFromTranslations ( rotCenSettingsPhased, symStr, allCAxes, relSym[0] )
+                point2                                = proshade.findPointFromTranslations ( rotCenSettingsPhased, symStr, allCAxes, relSym[1] )
+                
+                axis1                                 = numpy.array( [ allCAxes[relSym[0]][1], allCAxes[relSym[0]][2], allCAxes[relSym[0]][3]] )
+                axis2                                 = numpy.array( [ allCAxes[relSym[1]][1], allCAxes[relSym[1]][2], allCAxes[relSym[1]][3]] )
+                
+                tangentToAxes                         = numpy.cross ( axis1, axis2 )
+                correctedSecondAxis                   = numpy.cross ( axis1, tangentToAxes )
+                correctedFirstAxis                    = numpy.cross ( axis2, tangentToAxes )
+                
+                alpha1                                = numpy.dot ( point2 - point1, correctedFirstAxis  ) / numpy.dot ( axis1, correctedFirstAxis  )
+                alpha2                                = numpy.dot ( point1 - point2, correctedSecondAxis ) / numpy.dot ( axis2, correctedSecondAxis )
+                
+                cpVec                                 = numpy.zeros ( 3 )
+                cpVec[0]                              = ( ( point1[0] + ( alpha1 * axis1[0] ) ) + ( point2[0] + ( alpha2 * axis2[0] ) ) ) / 2.0
+                cpVec[1]                              = ( ( point1[1] + ( alpha1 * axis1[1] ) ) + ( point2[1] + ( alpha2 * axis2[1] ) ) ) / 2.0
+                cpVec[2]                              = ( ( point1[2] + ( alpha1 * axis1[2] ) ) + ( point2[2] + ( alpha2 * axis2[2] ) ) ) / 2.0
+                
+                pSet.setSymmetryCentrePosition        ( cpVec )
+            
+        ### If no symmetries, just be done
+        else:
+            print ( "No symmetry found in the Patterson map. Will try detecting symmetry over the centre of the box now..." )
+            del symStr
+
     ### Do all the computations
     pStruct.processInternalMap                        ( pSet )
     pStruct.mapToSpheres                              ( pSet )
@@ -304,6 +409,7 @@ def runProSHADESymmetry ( mapFile, maskFile, resol, chngSampl, cntrMap ):
     ### Retrieve results
     recSymmetryType                                   = pStruct.getRecommendedSymmetryType ( pSet )
     recSymmetryFold                                   = pStruct.getRecommendedSymmetryFold ( pSet )
+    recSymmetryAxes                                   = pStruct.getRecommendedSymmetryAxes ( pSet )
     allCAxes                                          = pStruct.getAllCSyms ( pSet )
     
     ### Convert results for return
@@ -311,6 +417,7 @@ def runProSHADESymmetry ( mapFile, maskFile, resol, chngSampl, cntrMap ):
     retList.append                                    ( recSymmetryType )
     retList.append                                    ( recSymmetryFold )
     retList.append                                    ( allCAxes )
+    retList.append                                    ( recSymmetryAxes )
     
     ### Release memory
     del pStruct
@@ -390,7 +497,7 @@ for entry in symIDs:
     startTime                                         = time.time ( )
 
     ### Run symmetry detection
-    symRes                                            = runProSHADESymmetry ( mapPath, maskPath, compResolution, mapReSampling, mapCentering )
+    symRes                                            = runProSHADESymmetry ( mapPath, maskPath, compResolution, mapReSampling, comCentering, symmetryCentering, verbosity )
 
     ### Stop timer
     stopTime                                          = time.time ( )
@@ -399,17 +506,26 @@ for entry in symIDs:
     print                                             ( " ... Symmetry detection complete ( time taken: " + str( stopTime - startTime ) + " )." )
 
     ### Open files for output
-    ( outResCondensed, outResAxes )                   = openOutputFiles ( counter )
+    ( outResRecom, outResCondensed, outResAxes )      = openOutputFiles ( counter )
 
     ### Write results
-    outResCondensed.write                             ( str( id ) + "\t" + str( declaredSym ) + "\t" + str( symRes[0]  ) + str( symRes[1] ) + "\t" + str( stopTime - startTime ) + "\n" )
+    if ( symRes[0] == "I" ) or ( symRes[0] == "O" ) or ( symRes[0] == "T" ):
+        outResCondensed.write                         ( str( id ) + "\t" + str( declaredSym ) + "\t" + str( symRes[0]  ) + "\t" + str( stopTime - startTime ) + "\n" )
+    else:
+        outResCondensed.write                         ( str( id ) + "\t" + str( declaredSym ) + "\t" + str( symRes[0]  ) + str( symRes[1] ) + "\t" + str( stopTime - startTime ) + "\n" )
+        
     outResAxes.write                                  ( str( id ) + " :\n==========\n" )
     for ax in range ( 0, len ( symRes[2] ) ):
         outResAxes.write                              ( str ( symRes[2][ax][0] ) + "\t" + str ( symRes[2][ax][1] ) + "\t" + str( symRes[2][ax][2] ) + "\t" + str( symRes[2][ax][3] ) + "\t" + str( symRes[2][ax][4] ) + "\t" + str( symRes[2][ax][5] ) + "\t" + str( symRes[2][ax][6] ) + "\t" + str( mapVolumeInds ) + "\t" + str( compResolution ) + "\n" )
     outResAxes.write                                  ( "\n" )
     
+    outResRecom.write                                 ( str( id ) + " :\n==========\n" )
+    for ax in range ( 0, len ( symRes[3] ) ):
+        outResRecom.write                             ( str ( symRes[3][ax][0] ) + "\t" + str ( symRes[3][ax][1] ) + "\t" + str( symRes[3][ax][2] ) + "\t" + str( symRes[3][ax][3] ) + "\t" + str( symRes[3][ax][4] ) + "\t" + str( symRes[3][ax][5] ) + "\t" + str( symRes[3][ax][6] ) + "\t" + str( mapVolumeInds ) + "\t" + str( compResolution ) + "\n" )
+    outResRecom.write                                  ( "\n" )
+    
     ### Close output files
-    closeOutputFiles                                  ( outResCondensed, outResAxes )
+    closeOutputFiles                                  ( outResRecom, outResCondensed, outResAxes )
     
     ### Move counter
     counter                                           = counter + 1
@@ -417,3 +533,4 @@ for entry in symIDs:
     ### End of symmetry detection for this structure
 
 ### Done
+
