@@ -15,8 +15,8 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.6.2
-    \date      DEC 2021
+    \version   0.7.6.3
+    \date      FEB 2022
  */
 
 //==================================================== ProSHADE
@@ -53,10 +53,11 @@ namespace ProSHADE_internal_io
     void readInMapData                                ( gemmi::Ccp4<int8_t> *gemmiMap, proshade_double*& map, proshade_unsign xDimInds, proshade_unsign yDimInds, proshade_unsign zDimInds,
                                                         proshade_unsign xAxOrder, proshade_unsign yAxOrder, proshade_unsign zAxOrder );
     void applyMask                                    ( proshade_double*& map, std::string maskFile, proshade_unsign xDimInds, proshade_unsign yDimInds, proshade_unsign zDimInds,
-                                                        proshade_signed verbose, proshade_signed messageShift, proshade_double* maskArray = nullptr, proshade_unsign maXInds = 0,
+                                                        proshade_signed verbose, proshade_signed messageShift, std::vector< proshade_double >* calcBounds, proshade_double* maskArray = nullptr, proshade_unsign maXInds = 0,
                                                         proshade_unsign maYInds = 0, proshade_unsign maZInds = 0 );
     void applyMaskFromArray                           ( proshade_double*& map, proshade_unsign xDimInds, proshade_unsign yDimInds, proshade_unsign zDimInds, proshade_double*& mask,
-                                                        proshade_unsign xDimIndsMsk, proshade_unsign yDimIndsMsk, proshade_unsign zDimIndsMsk, proshade_signed verbose, proshade_signed messageShift );
+                                                        proshade_unsign xDimIndsMsk, proshade_unsign yDimIndsMsk, proshade_unsign zDimIndsMsk, std::vector< proshade_double >* calcBounds,
+                                                        proshade_signed verbose, proshade_signed messageShift );
     void applyWeights                                 ( proshade_double*& map, std::string weightsFile, proshade_unsign xDimInds, proshade_unsign yDimInds, proshade_unsign zDimInds,
                                                         proshade_signed verbose, proshade_signed messageShift, proshade_double* weightsArray = nullptr, proshade_unsign waXInds = 0,
                                                         proshade_unsign waYInds = 0, proshade_unsign waZInds = 0 );
