@@ -15,8 +15,8 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.6.2
-    \date      DEC 2021
+    \version   0.7.6.3
+    \date      FEB 2022
  */
 
 //==================================================== ProSHADE
@@ -396,6 +396,23 @@ void ProSHADE_internal_tasks::SymmetryCentreDetectionTask ( ProSHADE_settings* s
         settings->centrePosition.at(2)                = std::numeric_limits< proshade_double >::infinity();
         return                                        ;
     }
+    else
+    {
+        std::stringstream ssHlp;
+        std::stringstream ssHlp2;
+        if ( relSym.size() == 1 )
+        {
+            ssHlp << "Decided that there is one reliable axis forming C" << allCs->at(relSym.at(0))[0];
+            ssHlp2 << "The axis is: [" << allCs->at(relSym.at(0))[1] << " , " << allCs->at(relSym.at(0))[2] << " , " << allCs->at(relSym.at(0))[3] << "] with angle " << allCs->at(relSym.at(0))[4] << " peak height " << allCs->at(relSym.at(0))[5] << " and average FSC of " << allCs->at(relSym.at(0))[6] << std::endl;
+        }
+        else
+        {
+            ssHlp << "Decided that there are two reliable axes forming D" << std::max ( allCs->at(relSym.at(0))[0], allCs->at(relSym.at(1))[0] );
+            ssHlp2 << "The first axis is:         [" << allCs->at(relSym.at(0))[1] << " , " << allCs->at(relSym.at(0))[2] << " , " << allCs->at(relSym.at(0))[3] << "] with angle " << allCs->at(relSym.at(0))[4] << " peak height " << allCs->at(relSym.at(0))[5] << " and average FSC of " << allCs->at(relSym.at(0))[6] << std::endl;
+            ssHlp2 << "   and the second axis is: [" << allCs->at(relSym.at(1))[1] << " , " << allCs->at(relSym.at(1))[2] << " , " << allCs->at(relSym.at(1))[3] << "] with angle " << allCs->at(relSym.at(1))[4] << " peak height " << allCs->at(relSym.at(1))[5] << " and average FSC of " << allCs->at(relSym.at(1))[6] << std::endl;
+        }
+        ProSHADE_internal_messages::printProgressMessage  ( settings->verbose, 2, ssHlp.str(), settings->messageShift );
+    }
     
     //================================================ Optimise the orthogonal pair, if there is one
     if ( relSym.size() == 2 )
@@ -455,14 +472,14 @@ void ProSHADE_internal_tasks::SymmetryCentreDetectionTask ( ProSHADE_settings* s
         ProSHADE_internal_mapManip::findMAPCOMValues  ( symStr->internalMap, &xMapCOM, &yMapCOM, &zMapCOM, symStr->xDimSize, symStr->yDimSize, symStr->zDimSize, symStr->xFrom, symStr->xTo, symStr->yFrom, symStr->yTo, symStr->zFrom, symStr->zTo );
         
         //============================================ Determine box centre in indices
-        proshade_double xBoxCentre                    = ( ( symStr->xTo - symStr->xFrom ) / 2 ) + symStr->xFrom;
-        proshade_double yBoxCentre                    = ( ( symStr->yTo - symStr->yFrom ) / 2 ) + symStr->yFrom;
-        proshade_double zBoxCentre                    = ( ( symStr->zTo - symStr->zFrom ) / 2 ) + symStr->zFrom;
+        proshade_double xBoxCentre                    = ( ( static_cast< proshade_double > ( symStr->xTo ) - static_cast< proshade_double > ( symStr->xFrom ) ) / 2.0 ) + static_cast< proshade_double > ( symStr->xFrom );
+        proshade_double yBoxCentre                    = ( ( static_cast< proshade_double > ( symStr->yTo ) - static_cast< proshade_double > ( symStr->yFrom ) ) / 2.0 ) + static_cast< proshade_double > ( symStr->yFrom );
+        proshade_double zBoxCentre                    = ( ( static_cast< proshade_double > ( symStr->zTo ) - static_cast< proshade_double > ( symStr->zFrom ) ) / 2.0 ) + static_cast< proshade_double > ( symStr->zFrom );
         
         //============================================ Determine distance from COM in indices to box centre in indices
-        proshade_double xCOMFromBoxCen                = xBoxCentre - ( xMapCOM / static_cast< proshade_double > ( symStr->xDimSize / symStr->xDimIndices ) );
-        proshade_double yCOMFromBoxCen                = yBoxCentre - ( yMapCOM / static_cast< proshade_double > ( symStr->yDimSize / symStr->yDimIndices ) );
-        proshade_double zCOMFromBoxCen                = zBoxCentre - ( zMapCOM / static_cast< proshade_double > ( symStr->zDimSize / symStr->zDimIndices ) );
+        proshade_double xCOMFromBoxCen                = xBoxCentre - ( xMapCOM / static_cast< proshade_double > ( symStr->xDimSize ) / static_cast< proshade_double > ( symStr->xDimIndices ) );
+        proshade_double yCOMFromBoxCen                = yBoxCentre - ( yMapCOM / static_cast< proshade_double > ( symStr->yDimSize ) / static_cast< proshade_double > ( symStr->yDimIndices ) );
+        proshade_double zCOMFromBoxCen                = zBoxCentre - ( zMapCOM / static_cast< proshade_double > ( symStr->zDimSize ) / static_cast< proshade_double > ( symStr->zDimIndices ) );
         
         //============================================ Determine the coefficient of mapping of the COM point to the line
         proshade_double alpha1                        = ProSHADE_internal_maths::computeDotProduct ( pointPos.at(0) - xCOMFromBoxCen,
